@@ -1,70 +1,107 @@
 "as.dudi" <- function (df, col.w, row.w, scannf, nf, call, type, tol = 1e-07,
-    full = FALSE) 
+                     full = FALSE)
 {
-    if (!is.data.frame(df)) 
-        stop("data.frame expected")
-    lig <- nrow(df)
-    col <- ncol(df)
-    if (length(col.w) != col) 
-        stop("Non convenient col weights")
-    if (length(row.w) != lig) 
-        stop("Non convenient row weights")
-    if (any(col.w) < 0) 
-        stop("col weight < 0")
-    if (any(row.w) < 0) 
-        stop("row weight < 0")
-    if (full) 
-        scannf <- FALSE
-    res <- list(tab = df, cw = col.w, lw = row.w)
-    df <- as.matrix(df)
-    df <- df * sqrt(row.w)
-    df <- sweep(df, 2, sqrt(col.w), "*")
-    svd1 <- svd(df)
-    eig <- svd1$d^2
-    rank <- sum((eig/eig[1]) > tol)
-    if (scannf) {
-        if (exists("ade4TkGUIFlag") && ade4TkGUIFlag) {
-            nf <- chooseaxes(eig, rank)
-        } else {
-            barplot(eig[1:rank])
-            cat("Select the number of axes: ")
-            nf <- as.integer(readLines(n = 1))
-        }
+  if (!is.data.frame(df))
+    stop("data.frame expected")
+  lig <- nrow(df)
+  col <- ncol(df)
+  if (length(col.w) != col)
+    stop("Non convenient col weights")
+  if (length(row.w) != lig)
+    stop("Non convenient row weights")
+  if (any(col.w) < 0)
+    stop("col weight < 0")
+  if (any(row.w) < 0)
+    stop("row weight < 0")
+  if (full)
+    scannf <- FALSE
+  transpose <- FALSE
+  if(lig<col)
+    transpose <- TRUE
+  res <- list(tab = df, cw = col.w, lw = row.w)
+  df <- as.matrix(df)
+  df.ori <- df
+  df <- df * sqrt(row.w)
+  df <- sweep(df, 2, sqrt(col.w), "*")
+  if(!transpose){
+    df <- crossprod(df,df) 
+  }
+  else{
+    df <- tcrossprod(df,df)
+  }
+  eig1 <- eigen(df,symmetric=TRUE)
+  eig <- eig1$values
+  rank <- sum((eig/eig[1]) > tol)
+  if (scannf) {
+    if (exists("ade4TkGUIFlag") && ade4TkGUIFlag) {
+      nf <- chooseaxes(eig, rank)
     }
-    if (nf <= 0) 
-        nf <- 2
-    if (nf > rank) 
-        nf <- rank
-    if (full) 
-        nf <- rank
-    res$eig <- eig[1:rank]
-    res$rank <- rank
-    res$nf <- nf
-    col.w[which(col.w == 0)] <- 1
+    else {
+      barplot(eig[1:rank])
+      cat("Select the number of axes: ")
+      nf <- as.integer(readLines(n = 1))
+    }
+  }
+  if (nf <= 0)
+    nf <- 2
+  if (nf > rank)
+    nf <- rank
+  if (full)
+    nf <- rank
+  res$eig <- eig[1:rank]
+  res$rank <- rank
+  res$nf <- nf
+  col.w[which(col.w == 0)] <- 1
+  row.w[which(row.w == 0)] <- 1
+  dval <- sqrt(res$eig)[1:nf]
+  if(!transpose){
     col.w <- 1/sqrt(col.w)
-    auxi <- data.frame(svd1$v[, 1:nf] * col.w)
+    auxi <- eig1$vectors[, 1:nf] * col.w
+    auxi2 <- sweep(df.ori, 2, res$cw, "*")
+    auxi2 <- data.frame(auxi2%*%auxi)
+    auxi <- data.frame(auxi)
+    
     names(auxi) <- paste("CS", (1:nf), sep = "")
     row.names(auxi) <- names(res$tab)
     res$c1 <- auxi
-    row.w[which(row.w == 0)] <- 1
+
+    names(auxi2) <- paste("Axis", (1:nf), sep = "")
+    row.names(auxi2) <- row.names(res$tab)
+    res$li <- auxi2
+
+    res$co <- sweep(res$c1,2,dval,"*")
+    names(res$co) <- paste("Comp", (1:nf), sep = "")
+
+    res$l1 <- sweep(res$li,2,dval,"/")
+    names(res$l1) <- paste("RS", (1:nf), sep = "")
+    
+
+  } else {
     row.w <- 1/sqrt(row.w)
-    auxi <- data.frame(svd1$u[, 1:nf] * row.w)
+    auxi <- eig1$vectors[, 1:nf] * row.w
+    auxi2 <- t(sweep(df.ori,1,res$lw,"*"))
+    auxi2 <- data.frame(auxi2%*%auxi)
+    auxi <- data.frame(auxi)
+    
     names(auxi) <- paste("RS", (1:nf), sep = "")
     row.names(auxi) <- row.names(res$tab)
     res$l1 <- auxi
-    w <- matrix(svd1$d[1:nf], col, nf, byr = TRUE)
-    auxi <- data.frame(as.matrix(res$c1) * w)
-    names(auxi) <- paste("Comp", (1:nf), sep = "")
-    row.names(auxi) <- names(res$tab)
-    res$co <- auxi
-    w <- matrix(svd1$d[1:nf], lig, nf, byr = TRUE)
-    auxi <- data.frame(as.matrix(res$l1) * w)
-    names(auxi) <- paste("Axis", (1:nf), sep = "")
-    row.names(auxi) <- row.names(res$tab)
-    res$li <- auxi
-    res$call <- call
-    class(res) <- c(type, "dudi")
-    return(res)
+    
+    names(auxi2) <- paste("Comp", (1:nf), sep = "")
+    row.names(auxi2) <- names(res$tab)
+    res$co <- auxi2
+
+    res$li <- sweep(res$l1,2,dval,"*")
+    names(res$li) <- paste("Axis", (1:nf), sep = "")
+
+    res$c1 <- sweep(res$co,2,dval,"/")
+    names(res$c1) <- paste("CS", (1:nf), sep = "")
+    
+  }
+  
+  res$call <- call
+  class(res) <- c(type, "dudi")
+  return(res)
 }
 
 
