@@ -5,27 +5,30 @@
     csub = 1.25, possub = "bottomleft", pixmap = NULL, contour = NULL, 
     area = NULL, add.plot = FALSE) { 
     
-    # if (!require(MASS)) stop("library MASS required for kde2d")
-    # kde2d is a function onf the library MASS
+    if (!require(MASS)) stop("library MASS required for kde2d")
+    # kde2d is a function of the library MASS
     # Venables, W. N. and Ripley, B. D. (2002) _Modern Applied
     # Statistics with S._ Fourth edition.  Springer.
-    "kde2d" <- function (x, y, h, n = 25, lims = c(range(x), range(y))) {
-        nx <- length(x)
-        if (length(y) != nx) 
-            stop("Data vectors must be the same length")
-        gx <- seq(lims[1], lims[2], length = n)
-        gy <- seq(lims[3], lims[4], length = n)
-        if (missing(h)) 
-            h <- c(bandwidth.nrd(x), bandwidth.nrd(y))
-        h <- h/4
-        ax <- outer(gx, x, "-")/h[1]
-        ay <- outer(gy, y, "-")/h[2]
-        z <- matrix(dnorm(ax), n, nx) %*% t(matrix(dnorm(ay), n, 
-            nx))/(nx * h[1] * h[2])
-        return(list(x = gx, y = gy, z = z))
-    }
+    # "kde2d" <- function (x, y, h, n = 25, lims = c(range(x), range(y))) {
+    #   nx <- length(x)
+    #   if (length(y) != nx) 
+    #       stop("Data vectors must be the same length")
+    #   gx <- seq(lims[1], lims[2], length = n)
+    #   gy <- seq(lims[3], lims[4], length = n)
+    #   if (missing(h)) 
+    #       h <- c(bandwidth.nrd(x), bandwidth.nrd(y))
+    #   h <- h/4
+    #   ax <- outer(gx, x, "-")/h[1]
+    #   ay <- outer(gy, y, "-")/h[2]
+    #   z <- matrix(dnorm(ax), n, nx) %*% t(matrix(dnorm(ay), n, 
+    #       nx))/(nx * h[1] * h[2])
+    #   return(list(x = gx, y = gy, z = z))
+    # }
+    # "bandwidth.nrd" <- function(x) {
+    #   r <- quantile(x, c(0.25, 0.75)) 
+    #   h <- (r[2] - r[1])/1.34 4 * 1.06 * min(sqrt(var(x)), h) * length(x)^(-1/5)
+    # } 
 
- 
     par(mar=c(0.1,0.1,0.1,0.1))
     s.label(dfxy, xax = xax, yax = yax, clab=0,
     pch = pch, cpoint = cpoint, neig = neig, 
