@@ -1,4 +1,4 @@
-"scatter.acm" <- function (x, xax = 1, yax = 2, csub = 2, possub = "topleft", ...) {
+"scatter.acm" <- function (x, xax = 1, yax = 2, mfrow=NULL, csub = 2, possub = "topleft", ...) {
     if (!inherits(x, "acm")) 
         stop("For 'acm' object")
     if (x$nf == 1) {
@@ -9,11 +9,16 @@
     on.exit(par(def.par))
     oritab <- eval(as.list(x$call)[[2]], sys.frame(0))
     nvar <- ncol(oritab)
-    par(mfrow = n2mfrow(nvar))
+    # modif samedi, juin 11, 2005 at 15:38 
+    # message de Ivailo Stoyanov istoyanov@ecolab.bas.bg
+    if (is.null(mfrow)) mfrow = n2mfrow(nvar)
+    old.par <- par(no.readonly = TRUE)
+    on.exit(par(old.par))
+    par(mfrow = mfrow)
+    if (prod(mfrow)<nvar) par(ask=T)
     # modif lundi, dcembre 16, 2002 at 16:48 
     # suite  message d'Alain Guerreau  
     for (i in 1:(nvar)) s.class(x$li, oritab[, i], xax=xax, yax=yax, clab = 1.5, 
         sub = names(oritab)[i], csub = csub, possub = possub, 
-        cgrid = 0, csta = 0)
+        cgrid = 0, csta = 0, ...)
 }
-
